Documentation
¶
Index ¶
- type Debugger
- func (d *Debugger) GetSymbolTable(prog string) *gosym.Table
- func (d *Debugger) InputOrContinue(pid int) bool
- func (d *Debugger) OutputStack(pid int, ip uint64, sp uint64, bp uint64)
- func (d *Debugger) ReplaceCode(pid int, address uint64, code []byte) []byte
- func (d *Debugger) Run()
- func (d *Debugger) RunTarget(target string)
- func (d *Debugger) SetBreak(pid int) (bool, []byte)
- type DebuggerInterface
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Debugger ¶
type Debugger struct {
TargetFile string
Line int
PC uint64
Fn *gosym.Func
SymTable *gosym.Table
Regs syscall.PtraceRegs
Ws syscall.WaitStatus
OriginalCode []byte
BreakpointSet bool
InterruptCode []byte
DebuggerInterface
}
Debugger holds the state of the debugger.
func (*Debugger) GetSymbolTable ¶
GetSymbolTable retrieves the symbol table from the specified executable.
func (*Debugger) InputOrContinue ¶
InputOrContinue gets user input to determine whether to continue, step, set a breakpoint, or quit.
func (*Debugger) OutputStack ¶
OutputStack outputs the call stack information.
func (*Debugger) ReplaceCode ¶
ReplaceCode replaces the code at the specified address with new code.
type DebuggerInterface ¶
Click to show internal directories.
Click to hide internal directories.